Crate flo_scene_guest

Crate flo_scene_guest 

flo_scene_guest

flo_scene is a runtime system for Rust that provides a platform for building large software out of much smaller components. See the flo_scene crate for details.

This provides a no_std implementation of the guest protocol used by flo_scene for dynamically loaded components. This is particularly useful for implementing guest programs in wasm, as this can produce considerably smaller assembly file sizes.

Re-exports

pub use runtime::GuestRuntime;
pub use exports::register_runtime;
pub use serde;
pub use postcard;
pub use futures;
pub use uuid;
pub use guest_types::*;
pub use host_types::*;

Modules

errors
exports
The functions that are exported to the host in order to allow it to communicate with the guest
guest_types
host_types
imports
External functions that are provided by the runtime to provide missing features
runtime
util